using UnityEngine;
using System.Collections;

public class CubeSpawnScript : MonoBehaviour {
	public Transform playerPrefab;
	
	void onNetworkLoadedLevel () {
		/*	Create the cube; this is called by whichever player joins the network.
		 * 	For example:
		 * 	01) Server starts the game
		 * 	02) Server's game calls onNetworkLoadedLevel()
		 * 	03) Client joins Server's game
		 * 	04) Client's game calls onNetworkLoadedLevel(); Server's game DOES NOT call onNetworkLoadedLevel()
		 * 
		 * 	Note: Class ConnectGUI is what actually calls onNetworkLoadedLevel().
		 * 		  Class ConnectGUI calls onNetworkLoadedLevel() when its OnConnectedToServer() is called or after
		 * 		  it initializes the server.
		*/
		Transform cube_transform = (Transform) Network.Instantiate(playerPrefab, transform.position, transform.rotation, 0) ;
		//Get the CubeMovement component; we need to make it belong to either the server or client
		CubeMovement cm = cube_transform.gameObject.GetComponent<CubeMovement>();
		
		//cm might possibly be null; check for it
		if (cm) { cm.setServerStatus(Network.isServer); }
	}
	
	void OnPlayerDisconnected (NetworkPlayer player) {
		//Refer to the following link for what RemoveRPCs() does:
		//http://forum.unity3d.com/threads/55392-Network.RemoveRPCs?p=353512&viewfull=#pos353512
		Network.RemoveRPCs(player, 0);
		//Refer to the following link for what DestroyPlayerObjects() does:
		//http://unity3d.com/support/documentation/ScriptReference/Network.DestroyPlayerObjects.html
		if (Network.isServer) {
			Network.DestroyPlayerObjects(player);
		}
	}

}
